@@ -25,19 +25,31 @@ import java.util.Set;
 
 class ColumnName extends Expression
 {
-	String columnName;
+	private String columnName;
+
 	public ColumnName(String columnName)
 	{
 		this.columnName = columnName.toUpperCase();
 	}
+
+	public String getColumnName()
+	{
+		return columnName;
+	}
+
+	@Override
 	public Object eval(Map<String, Object> env)
 	{
 		return env.get(columnName);
 	}
+
+	@Override
 	public String toString()
 	{
 		return "["+columnName+"]";
 	}
+
+	@Override
 	public List<String> usedColumns(Set<String> availableColumns)
 	{
 		List<String> result = new LinkedList<String>();
