@@ -117,6 +117,7 @@ public class CsvConnection implements Connection
 	private String timeFormat;
 	private String timeZoneName;
 	private Locale locale = null;
+	private boolean useDateTimeFormatter = CsvDriver.DEFAULT_USE_DATE_TIME_FORMATTER;
 	private String commentChar;
 
 	private int skipLeadingLines = 0;
@@ -305,6 +306,14 @@ public class CsvConnection implements Connection
 		if (info.getProperty(CsvDriver.SEPARATOR) != null)
 		{
 			separator = info.getProperty(CsvDriver.SEPARATOR);
+
+			// Tab character is a commonly used separator.
+			// Accept tab expanded to two characters '\\' and '\t'. This
+			// occurs if user types properties into a GUI text field,
+			// instead of writing them as Java source code.
+			if (separator.equals("\\t"))
+				separator = "\t";
+
 			if (separator.length() == 0)
 				throw new SQLException(CsvResources.getString("invalid") + " " + CsvDriver.SEPARATOR + ": " + separator);
 		}
@@ -378,7 +387,7 @@ public class CsvConnection implements Connection
 					"String").split(",");
 				String[] parameterStrings = info.getProperty("cryptoFilterParameters",
 					"").split(",");
-				StringConverter converter = new StringConverter("", "", "", "", null);
+				StringConverter converter = new StringConverter("", "", "", "", null, false);
 				Class<?>[] parameterClasses = new Class[parameterStrings.length];
 				Object[] parameterValues = new Object[parameterStrings.length];
 				for (int i = 0; i < parameterStrings.length; i++)
@@ -471,6 +480,10 @@ public class CsvConnection implements Connection
 			CsvDriver.DEFAULT_TIME_FORMAT));
 		setTimeZoneName(info.getProperty(CsvDriver.TIME_ZONE_NAME,
 			CsvDriver.DEFAULT_TIME_ZONE_NAME));
+		if (info.getProperty(CsvDriver.USE_DATE_TIME_FORMATTER) != null)
+		{
+			setUseDateTimeFormatter(Boolean.parseBoolean(info.getProperty(CsvDriver.USE_DATE_TIME_FORMATTER)));
+		}
 		if (info.getProperty(CsvDriver.LOCALE) != null)
 		{
 			prop = info.getProperty(CsvDriver.LOCALE);
@@ -584,6 +597,16 @@ public class CsvConnection implements Connection
 		return locale;
 	}
 
+	public void setUseDateTimeFormatter(boolean flag)
+	{
+		useDateTimeFormatter = flag;
+	}
+
+	public boolean getUseDateTimeFormatter()
+	{
+		return useDateTimeFormatter;
+	}
+
     private void checkOpen() throws SQLException
     {
     	if (closed)
@@ -1323,6 +1346,7 @@ public class CsvConnection implements Connection
 		// TODO Auto-generated method stub
 	}
 
+	@Override
 	public int getNetworkTimeout() throws SQLException
 	{
 		checkOpen();
@@ -1330,6 +1354,7 @@ public class CsvConnection implements Connection
 		return 0;
 	}
 
+	@Override
 	public void setNetworkTimeout(Executor executor, int milliseconds)
 		throws SQLException
 	{
@@ -1338,11 +1363,13 @@ public class CsvConnection implements Connection
 		throw new SQLFeatureNotSupportedException(CsvResources.getString("methodNotSupported") + ": Connection.setNetworkTimeout(Executor,int)");
 	}
 
+	@Override
 	public void abort(Executor executor) throws SQLException
 	{
 		throw new UnsupportedOperationException(CsvResources.getString("methodNotSupported") + ": Connection.abort(Executor)");
 	}
 
+	@Override
 	public String getSchema() throws SQLException
 	{
 		checkOpen();
@@ -1350,6 +1377,7 @@ public class CsvConnection implements Connection
 		return null;
 	}
 
+	@Override
 	public void setSchema(String schema) throws SQLException
 	{
 		checkOpen();
@@ -1388,6 +1416,7 @@ public class CsvConnection implements Connection
 		if (path != null)
 		{
 			File[] matchingFiles = new File(path).listFiles(new FilenameFilter() {
+				@Override
 				public boolean accept(File dir, String name)
 				{
 					return name.endsWith(extension);
