@@ -21,6 +21,7 @@ import java.io.IOException;
 import java.io.PrintStream;
 import java.io.PrintWriter;
 import java.io.UnsupportedEncodingException;
+import java.lang.reflect.InvocationTargetException;
 import java.net.URLDecoder;
 import java.sql.Connection;
 import java.sql.Date;
@@ -34,6 +35,7 @@ import java.sql.SQLFeatureNotSupportedException;
 import java.sql.Time;
 import java.sql.Timestamp;
 import java.sql.Types;
+import java.util.Enumeration;
 import java.util.Locale;
 import java.util.Properties;
 import java.util.logging.Logger;
@@ -58,6 +60,7 @@ public class CsvDriver implements Driver
 	public static final String DEFAULT_TIMESTAMP_FORMAT = null;
 	public static final String DEFAULT_DATE_FORMAT = "YYYY-MM-DD";
 	public static final String DEFAULT_TIME_FORMAT = "HH:mm:ss";
+	public static final boolean DEFAULT_USE_DATE_TIME_FORMATTER = false;
 	public static final String DEFAULT_COMMENT_CHAR = null;
 	public static final String DEFAULT_SKIP_LEADING_LINES = null;
 	public static final String DEFAULT_IGNORE_UNPARSEABLE_LINES = "False";
@@ -80,6 +83,7 @@ public class CsvDriver implements Driver
 	public static final String DATE_FORMAT = "dateFormat";
 	public static final String TIME_FORMAT = "timeFormat";
 	public static final String LOCALE = "locale";
+	public static final String USE_DATE_TIME_FORMATTER = "useDateTimeFormatter";
 	public static final String COMMENT_CHAR = "commentChar";
 	public static final String SKIP_LEADING_LINES = "skipLeadingLines";
 	public static final String IGNORE_UNPARSEABLE_LINES = "ignoreNonParseableLines";
@@ -137,6 +141,13 @@ public class CsvDriver implements Driver
 			return null;
 		}
 
+		Enumeration<Object> keys = info.keys();
+		while (keys.hasMoreElements())
+		{
+			String key = keys.nextElement().toString();
+			writeLog("CsvDriver:connect() - property " + key + "=" + info.getProperty(key));
+		}
+
 		// strip any properties from end of URL and set them as additional
 		// properties
 		String urlProperties = "";
@@ -199,7 +210,7 @@ public class CsvDriver implements Driver
 					throw new SQLException(CsvResources.getString("interfaceNotImplemented") +
 						": " + TableReader.class.getName() + ": " + className);
 				}
-				Object tableReaderInstance = clazz.newInstance();
+				Object tableReaderInstance = clazz.getConstructor().newInstance();
 				connection = new CsvConnection((TableReader)tableReaderInstance, info, urlProperties);
 			}
 			catch (ClassNotFoundException e)
@@ -214,6 +225,14 @@ public class CsvDriver implements Driver
 			{
 				throw new SQLException(e);
 			}
+			catch (InvocationTargetException e)
+			{
+				throw new SQLException(e);
+			}
+			catch (NoSuchMethodException e)
+			{
+				throw new SQLException(e);
+			}
 		}
 		else if (filePath.startsWith(ZIP_FILE_PREFIX))
 		{
@@ -268,6 +287,7 @@ public class CsvDriver implements Driver
 		return false;
 	}
 
+	@Override
 	public Logger getParentLogger() throws SQLFeatureNotSupportedException
 	{
 		throw new SQLFeatureNotSupportedException(CsvResources.getString("methodNotSupported") +
@@ -300,6 +320,7 @@ public class CsvDriver implements Driver
 		String timeFormat = DEFAULT_TIME_FORMAT;
 		String timestampFormat = DEFAULT_TIMESTAMP_FORMAT;
 		String timeZoneName = DEFAULT_TIME_ZONE_NAME;
+		boolean useDateTimeFormatter = DEFAULT_USE_DATE_TIME_FORMATTER;
 		Locale locale = null;
 
 		if (resultSet instanceof CsvResultSet)
@@ -317,9 +338,10 @@ public class CsvDriver implements Driver
 			timestampFormat = csvConnection.getTimestampFormat();
 			timeZoneName = csvConnection.getTimeZoneName();
 			locale = csvConnection.getLocale();
+			useDateTimeFormatter = csvConnection.getUseDateTimeFormatter();
 		}
 
-		StringConverter converter = new StringConverter(dateFormat, timeFormat, timestampFormat, timeZoneName, locale);
+		StringConverter converter = new StringConverter(dateFormat, timeFormat, timestampFormat, timeZoneName, locale, useDateTimeFormatter);
 
 		ResultSetMetaData meta = null;
 		int columnCount = 0;
