@@ -34,13 +34,13 @@ import java.sql.ResultSetMetaData;
 import java.sql.RowId;
 import java.sql.SQLException;
 import java.sql.SQLFeatureNotSupportedException;
+import java.sql.SQLTimeoutException;
 import java.sql.SQLWarning;
 import java.sql.SQLXML;
 import java.sql.Statement;
 import java.sql.Time;
 import java.sql.Timestamp;
 import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.Calendar;
 import java.util.Comparator;
 import java.util.HashMap;
@@ -140,6 +140,7 @@ public class CsvResultSet implements ResultSet
 	 */
 	public class OrderByComparator implements Comparator<Map<String, Object>>
 	{
+		@Override
 		public int compare(Map<String, Object> recordEnvironment1, Map<String, Object> recordEnvironment2)
 		{
 			int retval = 0;
@@ -256,7 +257,8 @@ public class CsvResultSet implements ResultSet
 		String timestampFormat = ((CsvConnection)statement.getConnection()).getTimestampFormat();
 		String timeZone = ((CsvConnection)statement.getConnection()).getTimeZoneName();
 		Locale locale = ((CsvConnection)statement.getConnection()).getLocale();
-		this.converter = new StringConverter(dateFormat, timeFormat, timestampFormat, timeZone, locale);
+		boolean useDateTimeFormatter = ((CsvConnection)statement.getConnection()).getUseDateTimeFormatter();
+		this.converter = new StringConverter(dateFormat, timeFormat, timestampFormat, timeZone, locale, useDateTimeFormatter);
 		if (reader instanceof CsvReader)
 		{
 			((CsvReader) reader).setConverter(converter);
@@ -841,26 +843,24 @@ public class CsvResultSet implements ResultSet
 
 	private void sortRows(int sqlOffset) throws SQLException
 	{
-		Map<String, Object> []allRows = new Map[bufferedRecordEnvironments.size()];
-		for (int i = 0; i < allRows.length; i++)
-			allRows[i] = bufferedRecordEnvironments.get(i);
+		ArrayList<Map<String, Object>> allRows = new ArrayList<Map<String, Object>>(bufferedRecordEnvironments);
 		bufferedRecordEnvironments.clear();
 		try
 		{
-			Arrays.sort(allRows, new OrderByComparator());
+			allRows.sort(new OrderByComparator());
 		}
 		catch (OrderByException e)
 		{
 			throw new SQLException(e.getMessage());
 		}
-		int rowLimit = allRows.length;
+		int rowLimit = allRows.size();
 		if (maxRows != 0 && maxRows < rowLimit)
 			rowLimit = maxRows;
 		if (limit >= 0 && sqlOffset + limit < rowLimit)
 			rowLimit = sqlOffset + limit;
 
 		for (int i = sqlOffset; i < rowLimit; i++)
-			bufferedRecordEnvironments.add(allRows[i]);
+			bufferedRecordEnvironments.add(allRows.get(i));
 	}
 
 	private void checkOpen() throws SQLException
@@ -869,12 +869,28 @@ public class CsvResultSet implements ResultSet
 			throw new SQLException(CsvResources.getString("closedResultSet"));
 	}
 
+	private void checkTimeout() throws SQLTimeoutException
+	{
+		if (statement.getTimeoutMillis() != Long.MAX_VALUE)
+		{
+			if (System.currentTimeMillis() >= statement.getTimeoutMillis())
+				throw new SQLTimeoutException();
+		}
+	}
+
 	@Override
 	public boolean next() throws SQLException
 	{
 		boolean thereWasAnAnswer;
 
 		checkOpen();
+		checkTimeout();
+
+		/*
+		 * Has query been cancelled by another thread?
+		 */
+		if (statement.isCancelled())
+			throw new SQLException(CsvResources.getString("statementCancelled"));
 
 		if ((this.groupByColumns != null ||
 		this.aggregateFunctions.size() > 0 ||
@@ -2768,12 +2784,14 @@ public class CsvResultSet implements ResultSet
 		// TODO Auto-generated method stub
 	}
 
+	@Override
 	public <T> T getObject(String columnLabel, Class<T> type) throws SQLException
 	{
 		throw new UnsupportedOperationException(CsvResources.getString("methodNotSupported") +
 			": ResultSet.getObject(String, Class<T>)");
 	}
 
+	@Override
 	public <T> T getObject(int columnIndex, Class<T> type) throws SQLException
 	{
 		throw new UnsupportedOperationException(CsvResources.getString("methodNotSupported") +
