@@ -27,7 +27,15 @@ import java.sql.Types;
 import java.text.DateFormatSymbols;
 import java.text.ParseException;
 import java.text.SimpleDateFormat;
+import java.time.LocalDate;
+import java.time.LocalDateTime;
+import java.time.LocalTime;
+import java.time.ZoneId;
+import java.time.ZonedDateTime;
+import java.time.format.DateTimeFormatter;
+import java.time.format.DateTimeFormatterBuilder;
 import java.util.ArrayList;
+import java.util.Calendar;
 import java.util.GregorianCalendar;
 import java.util.HashMap;
 import java.util.List;
@@ -52,67 +60,80 @@ public class StringConverter
 	private Pattern timestampPattern;
 	private SimpleDateFormat timestampFormat;
 	private SimpleDateFormat simpleDateFormat;
+	private int currentYear;
+
+	// Alternative Java 8 classes for parsing and formatting dates, times, timestamps.
+	DateTimeFormatter dateFormatter;
+	DateTimeFormatter timeFormatter;
+	DateTimeFormatter timestampFormatter;
 
 	public StringConverter(String dateformat, String timeformat, String timestampformat,
-		String timeZoneName)
+		String timeZoneName, boolean useDateTimeFormatter)
 	{
-		init(dateformat, timeformat, timestampformat, timeZoneName, null);
+		init(dateformat, timeformat, timestampformat, timeZoneName, null, useDateTimeFormatter);
 	}
 
 	public StringConverter(String dateformat, String timeformat, String timestampformat,
-		String timeZoneName, Locale locale)
+		String timeZoneName, Locale locale, boolean useDateTimeFormatter)
 	{
-		init(dateformat, timeformat, timestampformat, timeZoneName, locale);
+		init(dateformat, timeformat, timestampformat, timeZoneName, locale, useDateTimeFormatter);
 	}
 
 	private void init(String dateformat, String timeformat, String timestampformat,
-		String timeZoneName, Locale locale)
+		String timeZoneName, Locale locale, boolean useDateTimeFormatter)
 	{
 		dateFormat = dateformat;
 		if (dateformat != null)
 		{
-			/*
-			 * Can date be parsed with a simple regular expression, or is the full
-			 * SimpleDateFormat parsing required?
-			 */
-			// TODO prefer to use SimpleDateFormat for everything but existing regex not 100% compatible
-			String upper = dateformat.toUpperCase();
-			boolean useSimpleDateFormat = false;
-			if (upper.contains("MMM"))
+			if (useDateTimeFormatter)
 			{
-				/*
-				 * Dates contain named months -- we need to use a SimpleDateFormat to parse them.
-				 */
-				useSimpleDateFormat = true;
+				dateFormatter = createFormatter(dateFormat, locale, timeZoneName);
 			}
 			else
-			{
-				for (int i = 0; i < upper.length(); i++)
-				{
-					char c = upper.charAt(i);
-					if (Character.isLetter(c) && c != 'D' && c != 'M' && c != 'Y')
-					{
-						/*
-						 * Dates are not just a straightforward format with days, months,
-						 * years -- we need to use a SimpleDateFormat to parse them.
-						 */
-						useSimpleDateFormat = true;
-					}
-				}
-			}
-			if (useSimpleDateFormat)
 			{
 				/*
-				 * Use Java API for parsing dates.
+				 * Can date be parsed with a simple regular expression, or is the full
+				 * SimpleDateFormat parsing required?
 				 */
-				if (locale != null)
+				// TODO prefer to use SimpleDateFormat for everything but existing regex not 100% compatible
+				String upper = dateformat.toUpperCase(Locale.US);
+				boolean useSimpleDateFormat = false;
+				if (upper.contains("MMM"))
 				{
-					DateFormatSymbols symbols = DateFormatSymbols.getInstance(locale);
-					simpleDateFormat = new SimpleDateFormat(dateformat, symbols);
+					/*
+					 * Dates contain named months -- we need to use a SimpleDateFormat to parse them.
+					 */
+					useSimpleDateFormat = true;
 				}
 				else
 				{
-					simpleDateFormat = new SimpleDateFormat(dateformat);
+					for (int i = 0; i < upper.length(); i++)
+					{
+						char c = upper.charAt(i);
+						if (Character.isLetter(c) && c != 'D' && c != 'M' && c != 'Y')
+						{
+							/*
+							 * Dates are not just a straightforward format with days, months,
+							 * years -- we need to use a SimpleDateFormat to parse them.
+							 */
+							useSimpleDateFormat = true;
+						}
+					}
+				}
+				if (useSimpleDateFormat)
+				{
+					/*
+					 * Use Java API for parsing dates.
+					 */
+					if (locale != null)
+					{
+						DateFormatSymbols symbols = DateFormatSymbols.getInstance(locale);
+						simpleDateFormat = new SimpleDateFormat(dateformat, symbols);
+					}
+					else
+					{
+						simpleDateFormat = new SimpleDateFormat(dateformat);
+					}
 				}
 			}
 		}
@@ -121,46 +142,77 @@ public class StringConverter
 		 * Use Java API for parsing times.
 		 */
 		timeFormat = timeformat;
-		if (locale != null)
+		if (useDateTimeFormatter)
 		{
-			DateFormatSymbols symbols = DateFormatSymbols.getInstance(locale);
-			simpleTimeFormat = new SimpleDateFormat(timeformat, symbols);
+			timeFormatter = createFormatter(timeFormat, locale, timeZoneName);
 		}
 		else
 		{
-			simpleTimeFormat = new SimpleDateFormat(timeformat);
-		}
-
-		TimeZone timeZone = TimeZone.getTimeZone(timeZoneName);
-		calendar = new GregorianCalendar();
-		calendar.clear();
-		calendar.setTimeZone(timeZone);
-		if (timestampformat != null && timestampformat.length() > 0)
-		{
-			/*
-			 * Use Java API for parsing dates and times.
-			 */
 			if (locale != null)
 			{
 				DateFormatSymbols symbols = DateFormatSymbols.getInstance(locale);
-				timestampFormat = new SimpleDateFormat(timestampformat, symbols);
+				simpleTimeFormat = new SimpleDateFormat(timeformat, symbols);
 			}
 			else
 			{
-				timestampFormat = new SimpleDateFormat(timestampformat);
+				simpleTimeFormat = new SimpleDateFormat(timeformat);
 			}
-			timestampFormat.setTimeZone(timeZone);
+		}
+
+		if (useDateTimeFormatter)
+		{
+			if (timestampformat == null)
+				timestampformat = "yyyy-MM-dd HH:mm:ss";
+			timestampFormatter = createFormatter(timestampformat, locale, timeZoneName);
 		}
 		else
 		{
-			/*
-			 * Parse timestamps using a fixed regular expression.
-			 */
-			timestampPattern = Pattern
-				.compile("([0-9][0-9][0-9][0-9])-([0-9]?[0-9])-([0-9]?[0-9])[ T]([0-9]?[0-9]):([0-9]?[0-9]):([0-9]?[0-9]).*");
+			TimeZone timeZone = TimeZone.getTimeZone(timeZoneName);
+			calendar = new GregorianCalendar();
+			calendar.setTimeInMillis(System.currentTimeMillis());
+			currentYear = calendar.get(Calendar.YEAR);
+			calendar.clear();
+			calendar.setTimeZone(timeZone);
+			if (timestampformat != null && timestampformat.length() > 0)
+			{
+				/*
+				 * Use Java API for parsing dates and times.
+				 */
+				if (locale != null)
+				{
+					DateFormatSymbols symbols = DateFormatSymbols.getInstance(locale);
+					timestampFormat = new SimpleDateFormat(timestampformat, symbols);
+				}
+				else
+				{
+					timestampFormat = new SimpleDateFormat(timestampformat);
+				}
+				timestampFormat.setTimeZone(timeZone);
+			}
+			else
+			{
+				/*
+				 * Parse timestamps using a fixed regular expression.
+				 */
+				timestampPattern = Pattern
+					.compile("([0-9][0-9][0-9][0-9])-([0-9]?[0-9])-([0-9]?[0-9])[ T]([0-9]?[0-9]):([0-9]?[0-9]):([0-9]?[0-9]).*");
+			}
 		}
 	}
 
+	private DateTimeFormatter createFormatter(String pattern, Locale locale, String timeZoneName)
+	{
+		DateTimeFormatter formatter;
+		DateTimeFormatterBuilder builder = new DateTimeFormatterBuilder();
+		builder.parseCaseInsensitive();
+		builder.appendPattern(pattern);
+		if (locale != null)
+			formatter = builder.toFormatter(locale);
+		else
+			formatter = builder.toFormatter();
+		return formatter.withZone(ZoneId.of(timeZoneName));
+	}
+	
 	public String parseString(String str)
 	{
 		return str;
@@ -334,10 +386,11 @@ public class StringConverter
 	private String makeISODate(String date, String format)
 	{
 		// first memorize the original order of the groups.
-		format = format.toLowerCase();
+		format = format.toLowerCase(Locale.US);
 		int dpos = format.indexOf('d');
 		int mpos = format.indexOf('m');
 		int ypos = format.indexOf('y');
+		int ylen = 4;
 
 		int day = 1, month = 1, year = 1;
 		if (dpos > mpos)
@@ -370,7 +423,10 @@ public class StringConverter
 		part = Pattern.compile("y+");
 		m = part.matcher(format);
 		if (m.find())
+		{
+			ylen = m.end() - m.start();
 			format = format.replace(m.group(), "([0-9]{" + (m.end() - m.start()) + ",4})");
+		}
 
 		format = format + ".*";
 
@@ -380,6 +436,20 @@ public class StringConverter
 		{
 			// and return the groups in ISO8601 format.
 			String yearGroup = m.group(year);
+			if (yearGroup.length() == 2 && ylen == 2)
+			{
+				// Parsed year only contains two digits. Determine full year including
+				// century using same logic as java.text.SimpleDateFormat:
+				// select century that is less than 20 years in the future and
+				// less than 80 years in the past.
+				int century = currentYear / 100;
+				int proposedYear = (century * 100) + Integer.parseInt(yearGroup);
+				if (proposedYear - currentYear > 20)
+					proposedYear -= 100;
+				if (currentYear - proposedYear > 80)
+					proposedYear += 100;
+				yearGroup = String.format("%04d", proposedYear);
+			}
 			String monthGroup = m.group(month);
 			if (monthGroup.length() < 2)
 				monthGroup = "0" + monthGroup;
@@ -402,6 +472,11 @@ public class StringConverter
 			Date sqlResult = null;
 			if (str != null && str.length() > 0)
 			{
+				if (dateFormatter != null)
+				{
+					LocalDate localDate = LocalDate.parse(str, dateFormatter);
+					return Date.valueOf(localDate);
+				}
 				if (simpleDateFormat != null)
 				{
 					java.util.Date parsedDate = simpleDateFormat.parse(str);
@@ -425,21 +500,96 @@ public class StringConverter
 		}
 	}
 
+	/**
+	 * Create date string in format accepted by method {@link #parseDate(String) parseDate}.
+	 * @param d date to format.
+	 * @return formatted date.
+	 */
+	public String formatDate(Date d)
+	{
+		String formatted = null;
+
+		if (d != null)
+		{
+			if (dateFormatter != null)
+			{
+				formatted = d.toLocalDate().format(dateFormatter);
+			}
+			else if (simpleDateFormat != null)
+			{
+				formatted = simpleDateFormat.format(d);
+			}
+			else
+			{
+				formatted = dateFormat.toLowerCase(Locale.US);
+				Calendar gregorianCalendar = new GregorianCalendar();
+				gregorianCalendar.setTime(d);
+
+				// use regular expressions to replace in day, month, year in format string
+				Pattern part;
+				Matcher m;
+
+				part = Pattern.compile("d+");
+				m = part.matcher(formatted);
+				if (m.find())
+				{
+					int patternLength = m.end() - m.start();
+					String dayOfMonth = Integer.toString(gregorianCalendar.get(Calendar.DAY_OF_MONTH));
+					while (dayOfMonth.length() < patternLength)
+						dayOfMonth = "0" + dayOfMonth;
+					formatted = formatted.replace(m.group(), dayOfMonth);
+				}
+				part = Pattern.compile("m+");
+				m = part.matcher(formatted);
+				if (m.find())
+				{
+					int patternLength = m.end() - m.start();
+					String month = Integer.toString(gregorianCalendar.get(Calendar.MONTH) + 1);
+					while (month.length() < patternLength)
+						month = "0" + month;
+					formatted = formatted.replace(m.group(), month);
+				}
+				part = Pattern.compile("y+");
+				m = part.matcher(formatted);
+				if (m.find())
+				{
+					int patternLength = m.end() - m.start();
+					int fullYear = gregorianCalendar.get(Calendar.YEAR);
+					if (patternLength == 2)
+						fullYear = fullYear % 100;
+					String year = Integer.toString(fullYear);
+					while (year.length() < patternLength)
+						year = "0" + year;
+					formatted = formatted.replace(m.group(), year);
+				}
+			}
+		}
+		return formatted;
+	}
+
 	public Time parseTime(String str)
 	{
 		try
 		{
 			Time sqlResult = null;
-			if (str != null && str.length() > 0)
+			if (timeFormatter != null)
 			{
-				str = str.trim();
-				while (str.length() < timeFormat.length())
+				LocalTime localTime = LocalTime.parse(str, timeFormatter);
+				sqlResult = Time.valueOf(localTime);
+			}
+			else
+			{
+				if (str != null && str.length() > 0)
 				{
-					str = "0" + str;
-				} 
-				java.util.Date parsedDate = simpleTimeFormat.parse(str);
-				long millis = parsedDate.getTime();
-				sqlResult = new Time(millis);
+					str = str.trim();
+					while (str.length() < timeFormat.length())
+					{
+						str = "0" + str;
+					} 
+					java.util.Date parsedDate = simpleTimeFormat.parse(str);
+					long millis = parsedDate.getTime();
+					sqlResult = new Time(millis);
+				}
 			}
 			return sqlResult;
 		}
@@ -453,6 +603,29 @@ public class StringConverter
 		}
 	}
 
+	/**
+	 * Create time string in format accepted by method {@link #parseTime(String) parseTime}.
+	 * @param t time to format.
+	 * @return formatted time.
+	 */
+	public String formatTime(Time t)
+	{
+		String formatted = null;
+
+		if (t != null)
+		{
+			if (timeFormatter != null)
+			{
+				formatted = t.toLocalTime().format(timeFormatter);
+			}
+			else
+			{
+				formatted = simpleTimeFormat.format(t);
+			}
+		}
+		return formatted;
+	}
+
 	public Timestamp parseTimestamp(String str)
 	{
 		Timestamp result = null;
@@ -460,7 +633,12 @@ public class StringConverter
 		{
 			if (str != null && str.length() > 0)
 			{
-				if (timestampFormat != null)
+				if (timestampFormatter != null)
+				{
+					ZonedDateTime zonedDateTime = ZonedDateTime.parse(str, timestampFormatter);
+					result = Timestamp.from(zonedDateTime.toInstant());
+				}
+				else if (timestampFormat != null)
 				{
 					java.util.Date date = timestampFormat.parse(str);
 					result = new Timestamp(date.getTime());
@@ -491,6 +669,41 @@ public class StringConverter
 		return result;
 	}
 
+	/**
+	 * Create timestamp string in format accepted by method {@link #parseTimestamp(String) parseTimestamp}.
+	 * @param timestamp timestamp to format.
+	 * @return formatted timestamp.
+	 */
+	public String formatTimestamp(Timestamp timestamp)
+	{
+		String formatted = null;
+
+		if (timestamp != null)
+		{
+			if (timestampFormatter != null)
+			{
+				LocalDateTime localDateTime = LocalDateTime.ofInstant(timestamp.toInstant(), timestampFormatter.getZone());
+				formatted = localDateTime.format(timestampFormatter);
+			}
+			else if (timestampFormat != null)
+			{
+				formatted = timestampFormat.format(timestamp);
+			}
+			else
+			{
+				calendar.setTime(timestamp);
+				int year = calendar.get(Calendar.YEAR);
+				int month = calendar.get(Calendar.MONTH) + 1;
+				int dayOfMonth = calendar.get(Calendar.DAY_OF_MONTH);
+				int hourOfDay = calendar.get(Calendar.HOUR_OF_DAY);
+				int minutes = calendar.get(Calendar.MINUTE);
+				int seconds = calendar.get(Calendar.SECOND);
+				formatted = String.format("%04d-%02d-%02d %02d:%02d:%02d", year, month, dayOfMonth, hourOfDay, minutes, seconds);
+			}
+		}
+		return formatted;
+	}
+
 	public InputStream parseAsciiStream(String str)
 	{
 		return (str == null) ? null : new ByteArrayInputStream(str.getBytes());
@@ -559,7 +772,7 @@ public class StringConverter
 
 	public Class<?> forSQLName(String sqlTypeName)
 	{
-		sqlTypeName = sqlTypeName.toLowerCase();
+		sqlTypeName = sqlTypeName.toLowerCase(Locale.US);
 		return forSQLNameMap.get(sqlTypeName);
 	}
 
@@ -573,7 +786,7 @@ public class StringConverter
 	public static Object getLiteralForTypeName(String sqlTypeName)
 	{
 		Object retval = null;
-		sqlTypeName = sqlTypeName.toLowerCase();
+		sqlTypeName = sqlTypeName.toLowerCase(Locale.US);
 		if (sqlTypeName.equals("string"))
 			retval = "";
 		else if (sqlTypeName.equals("boolean"))
